==> haskell-topograph-1.0.0.2-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-topograph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 topograph
version:              1.0.0.2
visibility:           public
id:                   topograph-1.0.0.2-K5jLOlP43wD7dPPzw8dHZ
key:                  topograph-1.0.0.2-K5jLOlP43wD7dPPzw8dHZ
license:              BSD-3-Clause
copyright:            (c) 2018-2019 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/topograph
synopsis:             Directed acyclic graphs.
description:
    Directed acyclic graphs can be sorted topographically.
    Existence of topographic ordering allows writing many graph algorithms efficiently.
    And many graphs, e.g. most dependency graphs are acyclic!

    There are some algorithms built-in: dfs, transpose, transitive closure,
    transitive reduction...
    Some algorithms even become not-so-hard to implement, like a longest path!

category:             Data, Graph
abi:                  610bb0dafe12837b484fee2e1464238f
exposed:              True
exposed-modules:      Topograph
import-dirs:          /usr/lib/ghc-9.0.2/site-local/topograph-1.0.0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/topograph-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-topograph
hs-libraries:         HStopograph-1.0.0.2-K5jLOlP43wD7dPPzw8dHZ
depends:
    base-4.15.1.0 base-compat-0.12.2-l1EqrM7Qwu6Pq9d4drKFu
    base-orphans-0.8.7-MjeShQjeF5J3Ogz0js4Si containers-0.6.4.1
    vector-0.13.0.0-FO1psvzIWe996069p2V3EL

haddock-interfaces:   /usr/share/doc/haskell-topograph/html/topograph.haddock
haddock-html:         /usr/share/doc/haskell-topograph/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-topograph-1.0.0.2-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-topograph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 topograph
version:              1.0.0.2
visibility:           public
id:                   topograph-1.0.0.2-BsBKIbc4lHi2fGQh6zzSPk
key:                  topograph-1.0.0.2-BsBKIbc4lHi2fGQh6zzSPk
license:              BSD-3-Clause
copyright:            (c) 2018-2019 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/topograph
synopsis:             Directed acyclic graphs.
description:
    Directed acyclic graphs can be sorted topographically.
    Existence of topographic ordering allows writing many graph algorithms efficiently.
    And many graphs, e.g. most dependency graphs are acyclic!

    There are some algorithms built-in: dfs, transpose, transitive closure,
    transitive reduction...
    Some algorithms even become not-so-hard to implement, like a longest path!

category:             Data, Graph
abi:                  ed374d9d88c1737fa031f4dbed875c80
exposed:              True
exposed-modules:      Topograph
import-dirs:          /usr/lib/ghc-9.0.2/site-local/topograph-1.0.0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/topograph-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-topograph
hs-libraries:         HStopograph-1.0.0.2-BsBKIbc4lHi2fGQh6zzSPk
depends:
    base-4.15.1.0 base-compat-0.12.2-l1EqrM7Qwu6Pq9d4drKFu
    base-orphans-0.8.7-4HFhmuVAgae2MDg5rvjdQp containers-0.6.4.1
    vector-0.13.0.0-LLT9KXtmP0R46jFv7TPg0X

haddock-interfaces:   /usr/share/doc/haskell-topograph/html/topograph.haddock
haddock-html:         /usr/share/doc/haskell-topograph/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
